Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(610)

Unified Diff: base/android/apk_assets.h

Issue 2684433003: Files required by a service now listed in manifest. (Closed)
Patch Set: Fix build. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/BUILD.gn ('k') | base/android/apk_assets.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/android/apk_assets.h
diff --git a/base/android/apk_assets.h b/base/android/apk_assets.h
index 60d436bbb70e18f8c14596829f927b3bf695f269..cdac0000af603fc6fdcac07e77f2a10b495aeec2 100644
--- a/base/android/apk_assets.h
+++ b/base/android/apk_assets.h
@@ -8,8 +8,8 @@
#include <string>
#include "base/android/jni_android.h"
+#include "base/files/file_path.h"
#include "base/files/memory_mapped_file.h"
-#include "base/posix/global_descriptors.h"
namespace base {
namespace android {
@@ -26,11 +26,12 @@ BASE_EXPORT int OpenApkAsset(
const std::string& file_path,
base::MemoryMappedFile::Region* region);
// Registers an uncompressed asset from within the apk with GlobalDescriptors.
// Returns: true in case of success, false otherwise.
-BASE_EXPORT bool RegisterApkAssetWithGlobalDescriptors(
- base::GlobalDescriptors::Key key,
- const std::string& file_path);
+BASE_EXPORT bool RegisterApkAssetWithFileDescriptorStore(
+ const std::string& key,
+ const base::FilePath& file_path);
} // namespace android
} // namespace base
« no previous file with comments | « base/BUILD.gn ('k') | base/android/apk_assets.cc » ('j') | no next file with comments »
@@ -26,11 +26,12 @@ BASE_EXPORT int OpenApkAsset(
const std::string& file_path,
base::MemoryMappedFile::Region* region);
-// Registers an uncompressed asset from within the apk with GlobalDescriptors.
+// Registers an uncompressed asset from within the apk in the
+// FileDescriptorStore.
// Returns: true in case of success, false otherwise.

Powered by Google App Engine
This is Rietveld 408576698